<?php

namespace Drupal\onlyone;

use Drupal\Core\Url;
use Drupal\Core\Extension\ModuleHandlerInterface;
use Drupal\Core\Render\Markup;
use Drupal\Core\Render\RendererInterface;

/**
 * Class OnlyOne.
 */
class OnlyOneModuleHandler implements OnlyOneModuleHandlerInterface {

  /**
   * Drupal\Core\Extension\ModuleHandlerInterface definition.
   *
   * @var Drupal\Core\Extension\ModuleHandlerInterface
   */
  protected $moduleHandler;

  /**
   * Drupal\Core\Render\RendererInterface definition.
   *
   * @var Drupal\Core\Render\RendererInterface
   */
  protected $renderer;

  /**
   * Constructor.
   *
   * @param Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler.
   * @param Drupal\Core\Render\RendererInterface $renderer
   *   The renderer.
   */
  public function __construct(ModuleHandlerInterface $module_handler, RendererInterface $renderer) {
    $this->moduleHandler = $module_handler;
    $this->renderer = $renderer;
  }

  /**
   * {@inheritdoc}
   */
  public function getModuleHelpPageLink($module_machine_name, $module_name_alternate, $emphasize = FALSE) {
    // @todo Once Drupal 8.6 will be released the use of the function
    // system_rebuild_module_data() will be changed for the service
    // extension.list.module.
    // @see https://www.drupal.org/node/2709919
    // Getting all the modules information.
    $modules = system_rebuild_module_data();

    // Checking if the module is present in the site.
    if (isset($modules[$module_machine_name])) {
      // Getting the module name.
      $module_name = $modules[$module_machine_name]->info['name'];

      // If the module is installed and implement the hook_help.
      if (in_array($module_machine_name, $this->moduleHandler->getImplementations('help'))) {
        // Creating the link.
        $build = [
          '#type' => 'link',
          '#title' => $module_name,
          '#url' => Url::fromRoute('help.page', ['name' => $module_machine_name]),
          '#cache' => [
            'tags' => [
              'config:core.extension',
            ],
          ],
        ];
        // Rendering.
        $output = $this->renderer->render($build);
      }
      else {
        $output = $emphasize ? Markup::create('<em>' . $module_name . '</em>') : $module_name;
      }
    }
    else {
      // As the module is not present we use a alternate string.
      $output = $emphasize ? Markup::create('<em>' . $module_name_alternate . '</em>') : $module_name_alternate;
    }

    return $output;
  }

}
